@@ -2,7 +2,7 @@ package Test::TCP;
 use strict;
 use warnings;
 use 5.00800;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 use base qw/Exporter/;
 use IO::Socket::INET;
 use Params::Validate ':all';
@@ -28,22 +28,17 @@ sub empty_port {
 }
 
 sub test_tcp {
-    my %args = validate(@_, {
-        client => CODEREF,
-        server => CODEREF,
-        port   => {
-            type => SCALAR,
-            default => empty_port(),
-        },
-    });
-
-    my $port = $args{port};
+    my %args = @_;
+    for my $k (qw/client server/) {
+        die "missing madatory parameter $k" unless exists $args{$k};
+    }
+    my $port = $args{port} || empty_port();
 
     if ( my $pid = Test::SharedFork->fork() ) {
         # parent.
         wait_port($port);
 
-        $args{client}->($port);
+        $args{client}->($port, $pid);
 
         kill TERM => $pid;
         waitpid( $pid, 0 );
@@ -161,6 +156,10 @@ Waits for a particular port is available for connect.
 
 Tokuhiro Matsuno E<lt>tokuhirom@gmail.comE<gt>
 
+=head1 THANKS TO
+
+kazuhooku
+
 =head1 SEE ALSO
 
 =head1 LICENSE
